import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 工作履历服务对象基类
 *
 * @export
 * @class HRWorkRecordServiceBase
 * @extends {EntityServie}
 */
export default class HRWorkRecordServiceBase extends EntityService {

    /**
     * Creates an instance of  HRWorkRecordServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  HRWorkRecordServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof HRWorkRecordServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='hrworkrecord';
        this.APPDEKEY = 'hrworkrecordid';
        this.APPDENAME = 'hrworkrecords';
        this.APPDETEXT = 'hrworkrecordname';
        this.APPNAME = 'pim';
        this.SYSTEMNAME = 'ibizhumanresources';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRWorkRecordServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrworkrecord){
            let res:any = Http.getInstance().get(`/hremployees/${context.hremployee}/hrworkrecords/${context.hrworkrecord}/select`,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().get(`/hrworkrecords/${context.hrworkrecord}/select`,isloading);
            
            return res;
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRWorkRecordServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && true){
            let masterData:any = {};
            Object.assign(data,masterData);
            if(!data.srffrontuf || data.srffrontuf !== "1"){
                data[this.APPDEKEY] = null;
            }
            if(data.srffrontuf){
                delete data.srffrontuf;
            }
            let tempContext:any = JSON.parse(JSON.stringify(context));
            let res:any = await Http.getInstance().post(`/hremployees/${context.hremployee}/hrworkrecords`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        if(!data.srffrontuf || data.srffrontuf !== "1"){
            data[this.APPDEKEY] = null;
        }
        if(data.srffrontuf){
            delete data.srffrontuf;
        }
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/hrworkrecords`,data,isloading);
        
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRWorkRecordServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrworkrecord){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().put(`/hremployees/${context.hremployee}/hrworkrecords/${context.hrworkrecord}`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/hrworkrecords/${context.hrworkrecord}`,data,isloading);
            
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRWorkRecordServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrworkrecord){
            let res:any = Http.getInstance().delete(`/hremployees/${context.hremployee}/hrworkrecords/${context.hrworkrecord}`,isloading);
            return res;
        }
            let res:any = Http.getInstance().delete(`/hrworkrecords/${context.hrworkrecord}`,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRWorkRecordServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrworkrecord){
            let res:any = await Http.getInstance().get(`/hremployees/${context.hremployee}/hrworkrecords/${context.hrworkrecord}`,isloading);
            
            return res;
        }
            let res:any = await Http.getInstance().get(`/hrworkrecords/${context.hrworkrecord}`,isloading);
            
            return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRWorkRecordServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && true){
            let res:any = await Http.getInstance().get(`/hremployees/${context.hremployee}/hrworkrecords/getdraft`,isloading);
            res.data.hrworkrecord = data.hrworkrecord;
            
            return res;
        }
        let res:any = await  Http.getInstance().get(`/hrworkrecords/getdraft`,isloading);
        res.data.hrworkrecord = data.hrworkrecord;
        
        return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRWorkRecordServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrworkrecord){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hremployees/${context.hremployee}/hrworkrecords/${context.hrworkrecord}/checkkey`,data,isloading);
            
            return res;
        }
            let res:any = Http.getInstance().post(`/hrworkrecords/${context.hrworkrecord}/checkkey`,data,isloading);
            return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRWorkRecordServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && context.hrworkrecord){
            let masterData:any = {};
            Object.assign(data,masterData);
            let res:any = await Http.getInstance().post(`/hremployees/${context.hremployee}/hrworkrecords/${context.hrworkrecord}/save`,data,isloading);
            
            return res;
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/hrworkrecords/${context.hrworkrecord}/save`,data,isloading);
            
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof HRWorkRecordServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.hremployee && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            let res:any = Http.getInstance().get(`/hremployees/${context.hremployee}/hrworkrecords/fetchdefault`,tempData,isloading);
            return res;
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        let res:any = Http.getInstance().get(`/hrworkrecords/fetchdefault`,tempData,isloading);
        return res;
    }
}